{
    "$graph": [
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/bootstrap_samples"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "id": "#main/fragment_length"
                },
                {
                    "type": "File",
                    "id": "#main/index_file"
                },
                {
                    "type": "int",
                    "id": "#main/nthreads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/out_dir_name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/repo"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/run_ids"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "id": "#main/standard_deviation"
                }
            ],
            "steps": [
                {
                    "run": "#download-sra.cwl",
                    "in": [
                        {
                            "source": "#main/repo",
                            "id": "#main/download_sra/repo"
                        },
                        {
                            "source": "#main/run_ids",
                            "id": "#main/download_sra/run_ids"
                        }
                    ],
                    "out": [
                        "#main/download_sra/sraFiles"
                    ],
                    "id": "#main/download_sra"
                },
                {
                    "run": "#kallisto_quant_se.cwl",
                    "in": [
                        {
                            "source": "#main/bootstrap_samples",
                            "id": "#main/kallisto_quant/bootstrap_samples"
                        },
                        {
                            "source": "#main/pfastq_dump/fastqFiles",
                            "id": "#main/kallisto_quant/fq"
                        },
                        {
                            "source": "#main/fragment_length",
                            "id": "#main/kallisto_quant/fragment_length"
                        },
                        {
                            "source": "#main/index_file",
                            "id": "#main/kallisto_quant/index_file"
                        },
                        {
                            "source": "#main/out_dir_name",
                            "id": "#main/kallisto_quant/out_dir_name"
                        },
                        {
                            "source": "#main/standard_deviation",
                            "id": "#main/kallisto_quant/standard_deviation"
                        }
                    ],
                    "out": [
                        "#main/kallisto_quant/quant_output"
                    ],
                    "id": "#main/kallisto_quant"
                },
                {
                    "run": "#pfastq-dump.cwl",
                    "in": [
                        {
                            "source": "#main/nthreads",
                            "id": "#main/pfastq_dump/nthreads"
                        },
                        {
                            "source": "#main/download_sra/sraFiles",
                            "id": "#main/pfastq_dump/sraFiles"
                        }
                    ],
                    "out": [
                        "#main/pfastq_dump/fastqFiles"
                    ],
                    "id": "#main/pfastq_dump"
                }
            ],
            "id": "#main",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#main/kallisto_quant/quant_output",
                    "id": "#main/quant_output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "download-sra: A simple download tool to get .sra file",
            "doc": "A simple download tool to get .sra file from a repository of INSDC members. https://github.com/inutano/download-sra",
            "hints": [
                {
                    "dockerPull": "ghcr.io/inutano/download-sra:a827d85",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "download-sra"
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "ddbj",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "id": "#download-sra.cwl/repo"
                },
                {
                    "type": [
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#download-sra.cwl/run_ids"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*sra"
                    },
                    "id": "#download-sra.cwl/sraFiles"
                }
            ],
            "id": "#download-sra.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "kallisto quant: runs the quantification algorithm",
            "doc": "kallisto is a program for quantifying abundances of transcripts from RNA-Seq data, or more generally of target sequences using high-throughput sequencing reads. https://pachterlab.github.io/kallisto/manual.html#quant",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/kallisto:0.44.0--h7d86c95_2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "kallisto",
                "quant",
                "--single"
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(runtime.outdir)/$(inputs.out_dir_name)"
                }
            ],
            "inputs": [
                {
                    "label": "Perform sequence based bias correction",
                    "doc": "Perform sequence based bias correction",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--bias"
                    },
                    "id": "#kallisto_quant_se.cwl/bias"
                },
                {
                    "label": "Number of bootstrap samples",
                    "doc": "Number of bootstrap samples (default: 0)",
                    "type": "int",
                    "default": 0,
                    "inputBinding": {
                        "prefix": "--bootstrap-samples=",
                        "separate": false
                    },
                    "id": "#kallisto_quant_se.cwl/bootstrap_samples"
                },
                {
                    "label": "Tab separated file with chrosome names and lengths",
                    "doc": "Tab separated file with chrosome names and lengths (optional for --genomebam, but recommended)",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--chromosome"
                    },
                    "id": "#kallisto_quant_se.cwl/chromosome"
                },
                {
                    "label": "Input FASTQ file(s)",
                    "doc": "Input FASTQ file(s)",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#kallisto_quant_se.cwl/fq"
                },
                {
                    "label": "Strand specific reads, first read forward",
                    "doc": "Strand specific reads, first read forward",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--fr-stranded"
                    },
                    "id": "#kallisto_quant_se.cwl/fr_stranded"
                },
                {
                    "label": "Estimated average fragment length",
                    "doc": "Estimated average fragment length",
                    "type": [
                        "null",
                        "double"
                    ],
                    "default": 200,
                    "inputBinding": {
                        "prefix": "--fragment-length=",
                        "separate": false
                    },
                    "id": "#kallisto_quant_se.cwl/fragment_length"
                },
                {
                    "label": "Search for fusions for Pizzly",
                    "doc": "Search for fusions for Pizzly",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--fusion"
                    },
                    "id": "#kallisto_quant_se.cwl/fusion"
                },
                {
                    "label": "Project pseudoalignments to genome sorted BAM file",
                    "doc": "Project pseudoalignments to genome sorted BAM file",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--genomebam"
                    },
                    "id": "#kallisto_quant_se.cwl/genome_bam"
                },
                {
                    "label": "GTF file for transcriptome information",
                    "doc": "GTF file for transcriptome information (required for --genomebam)",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--gtf"
                    },
                    "id": "#kallisto_quant_se.cwl/gtf"
                },
                {
                    "label": "[Required] Filename for the kallisto index",
                    "doc": "Filename for the kallisto index to be used for quantification",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#kallisto_quant_se.cwl/index_file"
                },
                {
                    "label": "Number of threads",
                    "doc": "Number of threads to use (default: 1)",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--threads=",
                        "separate": false
                    },
                    "id": "#kallisto_quant_se.cwl/nthreads"
                },
                {
                    "label": "Name of the directory to write output to",
                    "doc": "Name of the directory to write output to (default: kallisto_quant)",
                    "type": "string",
                    "default": "kallisto_quant",
                    "id": "#kallisto_quant_se.cwl/out_dir_name"
                },
                {
                    "label": "Output plaintext instead of HDF5",
                    "doc": "Output plaintext instead of HDF5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--plaintext"
                    },
                    "id": "#kallisto_quant_se.cwl/plain_text"
                },
                {
                    "label": "Save pseudoalignments to transcriptome to BAM file",
                    "doc": "Save pseudoalignments to transcriptome to BAM file",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--pseudobam"
                    },
                    "id": "#kallisto_quant_se.cwl/pseudo_bam"
                },
                {
                    "label": "Strand specific reads, first read reverse",
                    "doc": "Strand specific reads, first read reverse",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--rf-stranded"
                    },
                    "id": "#kallisto_quant_se.cwl/rf_stranded"
                },
                {
                    "label": "Seed for the bootstrap sampling",
                    "doc": "Seed for the bootstrap sampling (default: 42)",
                    "type": "int",
                    "default": 42,
                    "inputBinding": {
                        "prefix": "--seed=",
                        "separate": false
                    },
                    "id": "#kallisto_quant_se.cwl/seed"
                },
                {
                    "label": "Include overhanged reads",
                    "doc": "Include reads where unobserved rest of fragment is predicted to lie outside a transcript",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--single-overhang"
                    },
                    "id": "#kallisto_quant_se.cwl/single_overhang"
                },
                {
                    "label": "Estimated standard deviation of fragment length",
                    "doc": "Estimated standard deviation of fragment length (default: -l, -s values are estimated from paired end data, but are required when using --single)",
                    "type": [
                        "null",
                        "double"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "prefix": "--sd=",
                        "separate": false
                    },
                    "id": "#kallisto_quant_se.cwl/standard_deviation"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.out_dir_name)"
                    },
                    "id": "#kallisto_quant_se.cwl/quant_output"
                }
            ],
            "id": "#kallisto_quant_se.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "pfastq-dump: A bash implementation of parallel-fastq-dump, parallel fastq-dump wrapper",
            "doc": "pfastq-dump is a bash implementation of parallel-fastq-dump, parallel fastq-dump wrapper. --stdout option is additionally supported, but almost same features. It also uses -N and -X options of fastq-dump to specify blocks of data to be decompressed separately. https://github.com/inutano/pfastq-dump",
            "hints": [
                {
                    "dockerPull": "quay.io/inutano/sra-toolkit:v2.9.0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "pfastq-dump"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--gzip"
                    },
                    "id": "#pfastq-dump.cwl/gzip"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#pfastq-dump.cwl/nthreads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--readids"
                    },
                    "id": "#pfastq-dump.cwl/readids"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--skip-technical"
                    },
                    "id": "#pfastq-dump.cwl/skip_technical"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--split-files"
                    },
                    "id": "#pfastq-dump.cwl/split_files"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--split-spot"
                    },
                    "id": "#pfastq-dump.cwl/split_spot"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#pfastq-dump.cwl/sraFiles"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*fastq*"
                    },
                    "id": "#pfastq-dump.cwl/fastqFiles"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*_1.fastq*"
                    },
                    "id": "#pfastq-dump.cwl/forward"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*_2.fastq*"
                    },
                    "id": "#pfastq-dump.cwl/reverse"
                }
            ],
            "id": "#pfastq-dump.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.18.owl",
        "https://schema.org/version/latest/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "https://schema.org/",
        "edam": "http://edamontology.org/"
    }
}
